@@ -1,17 +1,9 @@
 /*
- *
- * Copyright (C) 2006-2008 Sebastian Trueg <trueg@k3b.org>
- * Copyright (C) 2009-2011 Michal Malek <michalm@jabster.pl>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 2009-2011 Michal Malek <michalm@jabster.pl>
+    SPDX-FileCopyrightText: 1998-2008 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "k3bvideodvdrippingview.h"
 #include "k3bvideodvd.h"
@@ -281,7 +273,7 @@ void K3b::VideoDVDRippingView::reloadMedium()
         bool transcodeUsable = true;
 
         if( !k3bcore ->externalBinManager() ->foundBin( "transcode" ) ) {
-            KMessageBox::sorry( this,
+            KMessageBox::error( this,
                                 i18n("K3b uses transcode to rip Video DVDs. "
                                      "Please make sure it is installed.") );
             transcodeUsable = false;
@@ -295,7 +287,7 @@ void K3b::VideoDVDRippingView::reloadMedium()
                 if( K3b::VideoDVDTitleTranscodingJob::transcodeBinaryHasSupportFor( (K3b::VideoDVDTitleTranscodingJob::AudioCodec)i ) )
                     ++ac;
             if( !ac || !vc ) {
-                KMessageBox::sorry( this,
+                KMessageBox::error( this,
                                     i18n("<p>K3b uses transcode to rip Video DVDs. "
                                          "Your installation of transcode lacks support for any of the "
                                          "codecs supported by K3b."
